@@ -12,7 +12,7 @@ Usage::
     session_client: STSClient = session.client("sts")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, List, TYPE_CHECKING
+from typing import Any, Dict, List, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_sts.type_defs import (
     AssumeRoleResponseTypeDef,
@@ -32,20 +32,20 @@ __all__ = ("STSClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    ExpiredTokenException: Boto3ClientError
-    IDPCommunicationErrorException: Boto3ClientError
-    IDPRejectedClaimException: Boto3ClientError
-    InvalidAuthorizationMessageException: Boto3ClientError
-    InvalidIdentityTokenException: Boto3ClientError
-    MalformedPolicyDocumentException: Boto3ClientError
-    PackedPolicyTooLargeException: Boto3ClientError
-    RegionDisabledException: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    ExpiredTokenException: Type[Boto3ClientError]
+    IDPCommunicationErrorException: Type[Boto3ClientError]
+    IDPRejectedClaimException: Type[Boto3ClientError]
+    InvalidAuthorizationMessageException: Type[Boto3ClientError]
+    InvalidIdentityTokenException: Type[Boto3ClientError]
+    MalformedPolicyDocumentException: Type[Boto3ClientError]
+    PackedPolicyTooLargeException: Type[Boto3ClientError]
+    RegionDisabledException: Type[Boto3ClientError]
 
 
 class STSClient:
     """
-    [STS.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/sts.html#STS.Client)
+    [STS.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sts.html#STS.Client)
     """
 
     exceptions: Exceptions
@@ -64,7 +64,7 @@ class STSClient:
         TokenCode: str = None,
     ) -> AssumeRoleResponseTypeDef:
         """
-        [Client.assume_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/sts.html#STS.Client.assume_role)
+        [Client.assume_role documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sts.html#STS.Client.assume_role)
         """
 
     def assume_role_with_saml(
@@ -77,7 +77,7 @@ class STSClient:
         DurationSeconds: int = None,
     ) -> AssumeRoleWithSAMLResponseTypeDef:
         """
-        [Client.assume_role_with_saml documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/sts.html#STS.Client.assume_role_with_saml)
+        [Client.assume_role_with_saml documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sts.html#STS.Client.assume_role_with_saml)
         """
 
     def assume_role_with_web_identity(
@@ -91,19 +91,19 @@ class STSClient:
         DurationSeconds: int = None,
     ) -> AssumeRoleWithWebIdentityResponseTypeDef:
         """
-        [Client.assume_role_with_web_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
+        [Client.assume_role_with_web_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/sts.html#STS.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sts.html#STS.Client.can_paginate)
         """
 
     def decode_authorization_message(
         self, EncodedMessage: str
     ) -> DecodeAuthorizationMessageResponseTypeDef:
         """
-        [Client.decode_authorization_message documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/sts.html#STS.Client.decode_authorization_message)
+        [Client.decode_authorization_message documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sts.html#STS.Client.decode_authorization_message)
         """
 
     def generate_presigned_url(
@@ -114,17 +114,17 @@ class STSClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/sts.html#STS.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sts.html#STS.Client.generate_presigned_url)
         """
 
     def get_access_key_info(self, AccessKeyId: str) -> GetAccessKeyInfoResponseTypeDef:
         """
-        [Client.get_access_key_info documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/sts.html#STS.Client.get_access_key_info)
+        [Client.get_access_key_info documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sts.html#STS.Client.get_access_key_info)
         """
 
     def get_caller_identity(self) -> GetCallerIdentityResponseTypeDef:
         """
-        [Client.get_caller_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/sts.html#STS.Client.get_caller_identity)
+        [Client.get_caller_identity documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sts.html#STS.Client.get_caller_identity)
         """
 
     def get_federation_token(
@@ -136,12 +136,12 @@ class STSClient:
         Tags: List[TagTypeDef] = None,
     ) -> GetFederationTokenResponseTypeDef:
         """
-        [Client.get_federation_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/sts.html#STS.Client.get_federation_token)
+        [Client.get_federation_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sts.html#STS.Client.get_federation_token)
         """
 
     def get_session_token(
         self, DurationSeconds: int = None, SerialNumber: str = None, TokenCode: str = None
     ) -> GetSessionTokenResponseTypeDef:
         """
-        [Client.get_session_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.24/reference/services/sts.html#STS.Client.get_session_token)
+        [Client.get_session_token documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/sts.html#STS.Client.get_session_token)
         """
